@@ -1,4 +1,5 @@
 from django.core.mail.backends.base import BaseEmailBackend
+from django.conf import settings
 
 from .tasks import send_email
 
@@ -12,5 +13,10 @@ class CeleryEmailBackend(BaseEmailBackend):
         results = []
         kwargs['_backend_init_kwargs'] = self.init_kwargs
         for msg in email_messages:
-            results.append(send_email.delay(msg, **kwargs))
+            NO_DELAY = getattr(settings, 'DJCELERY_SES_NO_DELAY', False)
+            if NO_DELAY:
+                result = send_email(msg, **kwargs)
+            else:
+                result = send_email.delay(msg, **kwargs)
+            results.append(result)
         return results
